@@ -16,7 +16,7 @@
 
 import os
 import sys
-# import sudsds
+import calculate.contrib
 from suds import MethodNotFound
 from calculate.core.server.cert_cmd import getHwAddr, getIpLocal
 _ = lambda x: x
