@@ -29,13 +29,14 @@ class CoreWsdl(CoreServiceInterface):
     sid_locker = threading.Lock()
 
     # delete client session from file (close session)
-    def del_sid_from_file(self, sid):
+    @staticmethod
+    def del_sid_from_file(cls, sid):
         try:
             # temp file
-            sid_file = self.sids_file
+            sid_file = cls.sids_file
             sid_file_t = sid_file + 'temp'
 
-            with self.sid_locker:
+            with cls.sid_locker:
                 fd = open(sid_file, 'r')
                 ft = open(sid_file_t, 'w')
                 while True:
@@ -64,10 +65,11 @@ class CoreWsdl(CoreServiceInterface):
             return ['1']
 
     # find session id in file
-    def find_sid_in_file(self, sid):
-        sid_file = self.sids_file
+    @staticmethod
+    def find_sid_in_file(cls, sid):
+        sid_file = cls.sids_file
         # create, if file not exists
-        with self.sid_locker:
+        with cls.sid_locker:
             if not os.path.exists(sid_file):
                 temp = open(sid_file, 'w')
                 temp.close()
@@ -86,32 +88,34 @@ class CoreWsdl(CoreServiceInterface):
         return 0
 
     # add session id in file
-    def add_sid_in_file(self, sid, cert_id, lang):
+    @staticmethod
+    def add_sid_in_file(cls, sid, cert_id, lang):
         # list Format (session number, cert number, time start session)
         list_sid = [sid, cert_id, datetime.datetime.now()]
         # session's file
-        if not os.path.exists(self.sids):
-            os.mkdir(self.sids)
-        sids_dir = self.sids
+        if not os.path.exists(cls.sids):
+            os.mkdir(cls.sids)
+        sids_dir = cls.sids
         sid_file = sids_dir + "/%d.sid" % sid
 
         # create session's file
-        with self.sid_locker:
+        with cls.sid_locker:
             fp = open(sid_file, 'w')
             sid_list = [sid, 0, 0, lang]
             pickle.dump(sid_list, fp)
             fp.close()
 
             # add session in list sessions
-            fd = open(self.sids_file, 'a')
+            fd = open(cls.sids_file, 'a')
             pickle.dump(list_sid, fd)
             fd.close()
         return 0
 
-    def set_sid_lang(self, sid, lang):
-        sids_dir = self.sids
+    @staticmethod
+    def set_sid_lang(cls, sid, lang):
+        sids_dir = cls.sids
         sid_file = os.path.join(sids_dir, "%d.sid" % sid)
-        with self.sid_locker:
+        with cls.sid_locker:
             if not os.path.isfile(sid_file):
                 fp = open(sid_file, 'w')
                 fp.close()
@@ -128,42 +132,44 @@ class CoreWsdl(CoreServiceInterface):
             fp.close()
 
     # issue number of new session (and registered its)
-    def sid_cmp(self, sid, cert_id, lang):
-        if sid < 0 or sid > self.max_sid:
+    @staticmethod
+    def sid_cmp(cls, sid, cert_id, lang):
+        if sid < 0 or sid > cls.max_sid:
             sid = 0
         session = 1
         # if session is new
         if sid == 0:
             while True:
-                new_sid = random.randint(1, self.max_sid)
+                new_sid = random.randint(1, cls.max_sid)
                 # flag = 1 - exists, 0 - missing in SID_FILE
-                if self.find_sid_in_file(new_sid) == 0:
-                    self.add_sid_in_file(new_sid, cert_id, lang)
+                if cls.find_sid_in_file(cls, new_sid) == 0:
+                    cls.add_sid_in_file(cls, new_sid, cert_id, lang)
                     sid = new_sid
                     break
         # if session is old
         else:
             # find number in file registered
             # if not registered
-            if not self.find_sid_in_file(sid):
+            if not cls.find_sid_in_file(cls, sid):
                 # add session id in file
-                self.add_sid_in_file(sid, cert_id, lang)
+                cls.add_sid_in_file(cls, sid, cert_id, lang)
             else:
-                self.set_sid_lang(sid, lang)
+                cls.set_sid_lang(cls, sid, lang)
                 # set - old session
                 session = 0
 
         # session id and flag (new or old) session
         return [sid, session]
 
-    def serv_init_session(self, sid, lang):
+    @staticmethod
+    def serv_init_session(cls, sid, lang):
         day_cert = 600
         cur_thread = threading.currentThread()
         certificate = cur_thread.client_cert
         if certificate is None:
             return [-3], [0]
 
-        checked_id = find_cert_id(certificate, self.data_path, self.certbase)
+        checked_id = find_cert_id(certificate, cls.data_path, cls.certbase)
         try:
             if int(checked_id) < 1:
                 return [-4], [0]
@@ -171,7 +177,7 @@ class CoreWsdl(CoreServiceInterface):
             return [-4], [0]
         results = []
         cert_id = checked_id
-        with open(self.certbase) as fd:
+        with open(cls.certbase) as fd:
             t = fd.read()
             # See each line
             for line in t.splitlines():
@@ -196,14 +202,15 @@ class CoreWsdl(CoreServiceInterface):
         if not results:
             return [-4], [0]
 
-        return results, self.sid_cmp(sid, cert_id, lang)
+        return results, cls.sid_cmp(cls, sid, cert_id, lang)
 
-    def serv_sid_info(self, sid):
+    @staticmethod
+    def serv_sid_info(cls, sid):
         """ Get information about sid """
         cert_id = 0
         results = []
-        sid_file = self.sids_file
-        with self.sid_locker:
+        sid_file = cls.sids_file
+        with cls.sid_locker:
             fd = open(sid_file, 'r')
             while 1:
                 try:
@@ -220,8 +227,8 @@ class CoreWsdl(CoreServiceInterface):
         if cert_id == 0:
             return ["-1"]
 
-        with self.sid_locker:
-            with open(self.certbase) as fd:
+        with cls.sid_locker:
+            with open(cls.certbase) as fd:
                 t = fd.read()
                 # See each line
                 for line in t.splitlines():
@@ -239,9 +246,9 @@ class CoreWsdl(CoreServiceInterface):
                         results.append(words[5])
                         # client type
                         results.append(words[6])
-                        if not os.path.exists(self.sids):
-                            os.makedirs(self.sids)
-                        sid_path = self.sids + "/%d.sid" % sid
+                        if not os.path.exists(cls.sids):
+                            os.makedirs(cls.sids)
+                        sid_path = cls.sids + "/%d.sid" % sid
                         with open(sid_path) as fs:
                             # read info about session
                             sid_inf = pickle.load(fs)
