@@ -28,7 +28,7 @@ get_pkgname_by_filename = templateFunction.get_pkgname_by_filename
 
 
 class Cache(object):
-    reMerge = re.compile("(merge)\(([-\w/]*)(?:\[[^\]]\])?\)[-!=<>]")
+    reMerge = re.compile("(merge|mergepkg)\(([-\w/]*)(?:\[[^\]]\])?\)[-!=<>]")
     rePatch = re.compile("^#\s*Calculate.*ac_install_patch==on")
 
     PATCH_TYPE = "patch"
